==> haskell-quic-0.1.20-5-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-quic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quic
version:              0.1.20
visibility:           public
id:                   quic-0.1.20-1heaoVK4PZPFM4XZ4jPzEl
key:                  quic-0.1.20-1heaoVK4PZPFM4XZ4jPzEl
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             QUIC
description:
    Library for QUIC: A UDP-Based Multiplexed and Secure Transport

category:             Web
abi:                  3f419da230bc6508621e096542ae7c90
exposed:              True
exposed-modules:
    Network.QUIC Network.QUIC.Client Network.QUIC.Internal
    Network.QUIC.Server

hidden-modules:
    Network.QUIC.Client.Reader Network.QUIC.Client.Run
    Network.QUIC.Closer Network.QUIC.Common Network.QUIC.Config
    Network.QUIC.Connection Network.QUIC.Connection.Crypto
    Network.QUIC.Connection.Migration Network.QUIC.Connection.Misc
    Network.QUIC.Connection.PacketNumber Network.QUIC.Connection.Queue
    Network.QUIC.Connection.Role Network.QUIC.Connection.State
    Network.QUIC.Connection.Stream Network.QUIC.Connection.StreamTable
    Network.QUIC.Connection.Timeout Network.QUIC.Connection.Types
    Network.QUIC.Connector Network.QUIC.Crypto
    Network.QUIC.Crypto.Fusion Network.QUIC.Crypto.Keys
    Network.QUIC.Crypto.Nite Network.QUIC.Crypto.Types
    Network.QUIC.Crypto.Utils Network.QUIC.Event Network.QUIC.Exception
    Network.QUIC.Handshake Network.QUIC.IO Network.QUIC.Imports
    Network.QUIC.Info Network.QUIC.Logger Network.QUIC.Packet
    Network.QUIC.Packet.Decode Network.QUIC.Packet.Decrypt
    Network.QUIC.Packet.Encode Network.QUIC.Packet.Frame
    Network.QUIC.Packet.Header Network.QUIC.Packet.Number
    Network.QUIC.Packet.Token Network.QUIC.Parameters
    Network.QUIC.QLogger Network.QUIC.Qlog Network.QUIC.Receiver
    Network.QUIC.Recovery Network.QUIC.Recovery.Constants
    Network.QUIC.Recovery.Detect Network.QUIC.Recovery.Interface
    Network.QUIC.Recovery.LossRecovery Network.QUIC.Recovery.Metrics
    Network.QUIC.Recovery.Misc Network.QUIC.Recovery.PeerPacketNumbers
    Network.QUIC.Recovery.Persistent Network.QUIC.Recovery.Release
    Network.QUIC.Recovery.Timer Network.QUIC.Recovery.Types
    Network.QUIC.Recovery.Utils Network.QUIC.Sender
    Network.QUIC.Server.Reader Network.QUIC.Server.Run
    Network.QUIC.Stream Network.QUIC.Stream.Frag
    Network.QUIC.Stream.Misc Network.QUIC.Stream.Queue
    Network.QUIC.Stream.Reass Network.QUIC.Stream.Skew
    Network.QUIC.Stream.Table Network.QUIC.Stream.Types
    Network.QUIC.TLS Network.QUIC.Types Network.QUIC.Types.Ack
    Network.QUIC.Types.CID Network.QUIC.Types.Constants
    Network.QUIC.Types.Error Network.QUIC.Types.Exception
    Network.QUIC.Types.Frame Network.QUIC.Types.Integer
    Network.QUIC.Types.Packet Network.QUIC.Types.Queue
    Network.QUIC.Types.Resumption Network.QUIC.Types.Time
    Network.QUIC.Utils Network.QUIC.Windows

import-dirs:          /usr/lib/ghc-9.4.8/site-local/quic-0.1.20
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quic-0.1.20
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quic-0.1.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quic
hs-libraries:         HSquic-0.1.20-1heaoVK4PZPFM4XZ4jPzEl
depends:
    array-0.5.4.0 base-4.17.2.1
    base16-bytestring-1.0.2.0-ASFphLrgXvi67bm2qxzorY
    bytestring-0.11.5.3 containers-0.6.7
    crypto-token-0.1.1-Bbo06RTgIkk1YxzB0ySEwv
    crypton-1.0.3-16cGkRi6FF0JFIvaY823Of
    crypton-x509-1.7.7-7Vq2uspMh5s1VlFVkzsUh8
    crypton-x509-system-1.6.7-57zO3vOmVdh8ly154VcTlo
    data-default-class-0.1.2.0-J3yYo85AtrC9KKZSpt62Yc
    fast-logger-3.2.4-GrQ8nFhR5mpA8EuxDsGHQ2 filepath-1.4.2.2
    iproute-1.7.15-8uYeoR0nR2mCWKQ6kai7pc
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    network-3.1.4.0-BMQQjwbPvFR57Ka0tgIiy2
    network-byte-order-0.1.7-D2CHdiOOdOK1rEVBtge3lM
    network-control-0.1.1-C2MCLxv8szJG1d92ax8AqU
    network-udp-0.0.0-5sDWWZtgTJfE9RQHFmEad3
    random-1.2.1.3-KpmZVmsijPULH6l5PrmXSD
    serialise-0.2.6.1-F8dXTIVlKoKKTRi1WoerpP stm-2.5.1.0
    tls-2.0.6-IakNTBA0JiNDRPputM9FQX
    unix-time-0.4.17-8faXdsVwr5D7EOkCoBhjf4
    unliftio-0.2.25.1-83PwQVOhURl3H5nxoMcX3o
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:   /usr/share/doc/haskell-quic/html/quic.haddock
haddock-html:         /usr/share/doc/haskell-quic/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quic-0.1.24-8-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-quic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quic
version:              0.1.24
visibility:           public
id:                   quic-0.1.24-K0NORj2SaRC8me2Q1BkbzS
key:                  quic-0.1.24-K0NORj2SaRC8me2Q1BkbzS
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             QUIC
description:
    Library for QUIC: A UDP-Based Multiplexed and Secure Transport

category:             Web
abi:                  1c31947411dc5a724ffd338afa5f030e
exposed:              True
exposed-modules:
    Network.QUIC Network.QUIC.Client Network.QUIC.Internal
    Network.QUIC.Server

hidden-modules:
    Network.QUIC.Client.Reader Network.QUIC.Client.Run
    Network.QUIC.Closer Network.QUIC.Common Network.QUIC.Config
    Network.QUIC.Connection Network.QUIC.Connection.Crypto
    Network.QUIC.Connection.Migration Network.QUIC.Connection.Misc
    Network.QUIC.Connection.PacketNumber Network.QUIC.Connection.Queue
    Network.QUIC.Connection.Role Network.QUIC.Connection.State
    Network.QUIC.Connection.Stream Network.QUIC.Connection.StreamTable
    Network.QUIC.Connection.Timeout Network.QUIC.Connection.Types
    Network.QUIC.Connector Network.QUIC.Crypto
    Network.QUIC.Crypto.Fusion Network.QUIC.Crypto.Keys
    Network.QUIC.Crypto.Nite Network.QUIC.Crypto.Types
    Network.QUIC.Crypto.Utils Network.QUIC.Event Network.QUIC.Exception
    Network.QUIC.Handshake Network.QUIC.IO Network.QUIC.Imports
    Network.QUIC.Info Network.QUIC.Logger Network.QUIC.Packet
    Network.QUIC.Packet.Decode Network.QUIC.Packet.Decrypt
    Network.QUIC.Packet.Encode Network.QUIC.Packet.Frame
    Network.QUIC.Packet.Header Network.QUIC.Packet.Number
    Network.QUIC.Packet.Token Network.QUIC.Parameters
    Network.QUIC.QLogger Network.QUIC.Qlog Network.QUIC.Receiver
    Network.QUIC.Recovery Network.QUIC.Recovery.Constants
    Network.QUIC.Recovery.Detect Network.QUIC.Recovery.Interface
    Network.QUIC.Recovery.LossRecovery Network.QUIC.Recovery.Metrics
    Network.QUIC.Recovery.Misc Network.QUIC.Recovery.PeerPacketNumbers
    Network.QUIC.Recovery.Persistent Network.QUIC.Recovery.Release
    Network.QUIC.Recovery.Timer Network.QUIC.Recovery.Types
    Network.QUIC.Recovery.Utils Network.QUIC.Sender
    Network.QUIC.Server.Reader Network.QUIC.Server.Run
    Network.QUIC.Stream Network.QUIC.Stream.Frag
    Network.QUIC.Stream.Misc Network.QUIC.Stream.Queue
    Network.QUIC.Stream.Reass Network.QUIC.Stream.Skew
    Network.QUIC.Stream.Table Network.QUIC.Stream.Types
    Network.QUIC.TLS Network.QUIC.Types Network.QUIC.Types.Ack
    Network.QUIC.Types.CID Network.QUIC.Types.Constants
    Network.QUIC.Types.Error Network.QUIC.Types.Exception
    Network.QUIC.Types.Frame Network.QUIC.Types.Info
    Network.QUIC.Types.Integer Network.QUIC.Types.Packet
    Network.QUIC.Types.Queue Network.QUIC.Types.Resumption
    Network.QUIC.Types.Time Network.QUIC.Utils Network.QUIC.Windows

import-dirs:          /usr/lib/ghc-9.4.8/site-local/quic-0.1.24
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quic-0.1.24
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quic-0.1.24
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quic
hs-libraries:         HSquic-0.1.24-K0NORj2SaRC8me2Q1BkbzS
depends:
    array-0.5.4.0 base-4.17.2.1
    base16-bytestring-1.0.2.0-1Uz6oHjhPf9KewF5fWee2u
    bytestring-0.11.5.3 containers-0.6.7
    crypto-token-0.1.2-ZNC0STf4g91FPIFWm4O1e
    crypton-1.0.4-AGWvxb3uQebCjfbnRIxIRG
    crypton-x509-1.7.7-LO0JNxlDO76GFu3tCrYMOE
    crypton-x509-system-1.6.7-7PfSsfL5yxd9XPi4iirL8E
    data-default-class-0.1.2.2-2EcHBs5cfSFLku8331ZnRi
    fast-logger-3.2.4-CmUTOIzlIrP2oPyQXhvG8f filepath-1.4.2.2
    iproute-1.7.15-IoFRJjkKKQuBZdpOmF2qle
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    network-3.1.4.0-2g2oEkgQCahBaM3HvlpVNW
    network-byte-order-0.1.7-D2CHdiOOdOK1rEVBtge3lM
    network-control-0.1.3-7QoKGuZ9EQq8rU5EXpSb0Z
    network-udp-0.0.0-AOhEPdNTR3oKcHMdQ41JFV
    random-1.2.1.3-KY8hXIsRO0nEsZvihu4hBT
    serialise-0.2.6.1-EctFCD5KUkFBHlRXLD4kc7 stm-2.5.1.0
    tls-2.0.6-I1Ld4heBgrMIPyOIwAkQZM
    unix-time-0.4.17-2jxFr0YqGPeL4FwIosdzld
    unliftio-0.2.25.1-jUDvU4O8PS8SoQvWmG5yt
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:   /usr/share/doc/haskell-quic/html/quic.haddock
haddock-html:         /usr/share/doc/haskell-quic/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
